<?php
namespace HCM\BTL\Controllers;

use \Zeedhi\Framework\DTO\Response;
use HCM\Util\Util;

class CandidatosController {

    protected $candidatosServices;
    CONST operatorLikeAll = 'LIKE_ALL';
    CONST operatorLike = 'LIKE';

    public function __construct(\HCM\BTL\Services\CandidatosServices $candidatosServices) {
        $this->candidatosServices = $candidatosServices;
    }

    public function getCandidatosGeral($request, $response) {

        try {
            ini_set('memory_limit', '2048M');
            $filters = $request->getFilterCriteria()->getConditions();
            $parameters = array();
            $fieldsUnset = array('IDADEMINIMA', 'IDADEMAXIMA', 'SALARIOMINIMO', 'SALARIOMAXIMO', 'DSINSTITUICAO', 'NRAREAFORMACAO', 'NRCURSO', 'DSCURSO', 'DES_AREAFORMACAO_NRORG', 'CDIDIOM', 'NROCUPACAOM', 'DSOCUPACAO', 'IDCADASTROCOMPLETO', 'NMESTADO');
            foreach ($filters as $key => $filter) {
                if (array_search($filter['columnName'], $fieldsUnset) !== false){
                    unset($filters[$key]);
                }
                if($filter['operator'] == self::operatorLikeAll){
                    $filters[0]['operator'] = self::operatorLike;
                    $filters[0]['columnName'] = str_replace('|', '||', $filter['columnName']);
                }
                $parameters[$filter['columnName']] = $filter['value'];
            }
            $result = $this->candidatosServices->getCandidatosGeral($parameters, $filters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getCandidatosGeral', $result));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function getCandidatos($request, $response) {

        try {

            $filters = $request->getFilterCriteria()->getConditions();
            $parameters = array();
            foreach ($filters as $position => $filter) {
                unset($filter['operator']);
                foreach ($filter as $key => $value) {
                    if ($key == 'columnName') {
                        $parameters[$value] = $filter['value'];
                    }
                }
                if($filter['columnName'] == "P_PARECERFINAL"){
                    unset($filters[$position]);
                }
            }
            Util::getValueInFilterDataSourceByName($filters, array('P_NRPROCESSO', 'P_IDPARTIPAPROCESSO'), true);
            $conditions = Util::createQueryFiltered($filters);
            $result = $this->candidatosServices->getCandidatos($parameters, $conditions);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getCandidatosCadastrados', $result));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function adicionarCandidatoProcesso($request, $response) {

        try {

            $dataset = $request->getDataSet();
            $dataset = $dataset->getRows();
            if(empty($dataset[0][0])){
                $this->candidatosServices->adicionarCandidatoProcesso($dataset[0]);
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('save', $dataset));
            } else {
                foreach ($dataset[0] as $row) {
                    $this->candidatosServices->adicionarCandidatoProcesso($row);
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('save', array(true)));
                }
            }

        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function removerCandidatoProcesso($request, $response) {

        try {

            $dataset = $request->getDataSet();
            $dataset = $dataset->getRows();
            $dataset = $dataset[0];

            $this->candidatosServices->removerCandidatoProcesso($dataset);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('delete', array(true)));

        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }

    }

    public function buscarAnexoCurriculo($request, $response){
        try{
            $curriculoAnexo = 'https://talentos.pebbian.com/mobile/files/uploads/'.$request->getDataSet()->getRows()[0]['NRORG'].'/'.'curriculo'.'/'.$request->getDataSet()->getRows()[0]['NRPESSOA'];

            $caminho = '';
            $curriculo = '';
            if (file_exists($curriculoAnexo.'.doc')) {
                $caminho = $curriculoAnexo.'.doc';
                 if(!array_key_exists('ANEXARCURRICULO',  $request->getDataSet()->getRows())) {
                    $curriculo['ANEXARCURRICULO'] = true;
                    $curriculo['CAMINHO'] = $caminho;
                }
            } elseif (file_exists($curriculoAnexo.'.docx')) {
                $caminho = $curriculoAnexo.'.docx';
                if(!array_key_exists('ANEXARCURRICULO',  $request->getDataSet()->getRows())) {
                    $curriculo['ANEXARCURRICULO'] = true;
                    $curriculo['CAMINHO'] = $caminho;
                }
            } elseif (file_exists($curriculoAnexo.'.pdf')){
                $caminho = $curriculoAnexo.'.pdf';
                if(!array_key_exists('ANEXARCURRICULO',  $request->getDataSet()->getRows())) {
                    $curriculo['ANEXARCURRICULO'] = true;
                    $curriculo['CAMINHO'] = $caminho;
               }
            }

            $fotoAnexo = 'https://talentos.pebbian.com/mobile/files/uploads/'.$request->getDataSet()->getRows()[0]['NRORG'].'/'.'foto'.'/'.$request->getDataSet()->getRows()[0]['NRPESSOA'];
            $foto = '';
            if (file_exists($fotoAnexo.'.jpg')) {
                $caminho = $fotoAnexo.'.jpg';
                if(!array_key_exists('ANEXARFOTO',  $request->getDataSet()->getRows())){
                    $foto['ANEXARFOTO'] = true;
                    $foto['CAMINHO'] = $caminho;
                }
            } elseif (file_exists($fotoAnexo.'.jpeg')) {
                $caminho = $fotoAnexo.'.jpeg';
                if(!array_key_exists('ANEXARFOTO',  $request->getDataSet()->getRows())){
                    $foto['ANEXARFOTO'] = true;
                    $foto['CAMINHO'] = $caminho;
                }
            } elseif (file_exists($fotoAnexo.'.png')){
                $caminho = $fotoAnexo.'.png';
                if(!array_key_exists('ANEXARFOTO',  $request->getDataSet()->getRows())){
                    $foto['ANEXARFOTO'] = true;
                    $foto['CAMINHO'] = $caminho;
                }
            }   

            $teste = array($request->getDataSet()->getRows()[0], $foto, $curriculo);

            $teste2 = new \Zeedhi\Framework\DataSource\DataSet('procurarCurriculo', array($teste));
            $response->addDataSet($teste2);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}