<?php

namespace HCM\FPA\Entity;

use HCM\Util\Repositories;
use HCM\Util\TkEntity;
use Zeedhi\Framework\ORM\DateTime;
use \Teknisa\Model\Gestaopessoas\Entities\FpaCagedmagnet;
use Teknisa\Model\Gestaopessoas\Entities\GpeTpmovtransfm;

class FpaCagedmagnetEntity extends TkEntity {


    public function __construct($entityManager, $hcmParameters) {
        $this->hcmParameters = $hcmParameters;
        $this->fpa_cagedmagnet = Repositories::FPA_CAGEDMAGNET;
        parent::__construct(null,$entityManager);
    }
    /**
     * Retorna registros.
     *
     * @param TkDateTime $mesCompetencia Mes de competencia.
     * @param integer    $nrorg          Numero da organizacao.
     *
     * @return array FpacagedmagnetEntity
     *g
     */
    public function retornaRegistros($mesCompetencia, $nrorg, $cdOperador){
        return $this->entityManager->getRepository(Repositories::FPA_CAGEDMAGNET)->findBy(
            array('nrorg' => $nrorg, 'mescompetencia' => $mesCompetencia, 'cdoperinclusao' => $cdOperador),
            array('idtpinscestrutu' => 'ASC', 'cdinscestrut' => 'ASC', 'idtiporegistro' => 'ASC', 'nrpispaseppes' => 'ASC'));
    } 


    /**
     * Cria lista de objetos FpacagedmagnetEntity conforme array de tipo de registros.
     *
     * @param string $mesCompetencia    Mes de competencia.
     * @param string $listaTipoRegistro Lista com os tipos de registros.
     * @param string $nrorg             Numero da Organizacao.
     *
     * @return boolean
     *
     */
    public function inicializaListaRegistros($mesCompetencia, $listaTipoRegistro, $nrorg){
        $resultados = $this->entityManager->getRepository(Repositories::FPA_CAGEDMAGNET)->findBy(array('nrorg' => $nrorg,
        'mescompetencia' => $mesCompetencia,'idtiporegistro' => $listaTipoRegistro));
        if (is_array($resultados) === true) {
            foreach ($resultados as $resultado) {
                $this->addItem($resultado, $resultado->getNrcagedmagnet());
            }
            return true;
        } else {
            return false;
        }
    }

    /**
     * Adiciona registro na lista.
     *
     * @param string $nrorg                Numero da Organizacao.
     * @param string $mesCompetencia       Mes de competencia.
     * @param string $tipoRegistro         Numero do tipo de registro.
     * @param string $tipoInscricao        Numero do tipo de inscricao.
     * @param string $nrInscricao          Numero da inscricao.
     * @param string $linha                Linha do registro CAGED.
     * @param string $nrVinculo            Numero do vinculo.
     * @param string $dtAdmissao           Data de Admissao.
     * @param string $nrPisPasepCi         Numero de inscricao PIS / PASEP / CI.
     *
     * @return void
     *
     */
    public function insereRegistroLista(
        $nrorg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao, $linha,
        $nrVinculo = null, $dtAdmissao = null, $nrPisPasepCi = "0", $qtVincativos = null
    ){

        $item = new  \Teknisa\Model\Gestaopessoas\Entities\FpaCagedmagnet();
        
        $item->setIdativo('S'); // Verificar.
        $item->setNrorg($nrorg);
        $item->setMescompetencia($mesCompetencia);
        $item->setIdtiporegistro($tipoRegistro);
        $item->setIdtpinscestrutu($tipoInscricao);
        $item->setCdinscestrut($nrInscricao);
        $item->setDslinharegistro($linha);
        $item->setNrorginclusao($nrorg);
        $item->setNrorgultatu($nrorg);
        $item->setDtultatu(new DateTime());
        $item->setDtinclusao(new DateTime());
        $item->setCdoperultatu($this->hcmParameters->getCdoperador());
        $item->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $item->setNrvinculom($nrVinculo);
        $item->setDtadmissaovinc($dtAdmissao);
        $item->setNrpispaseppes($nrPisPasepCi);
        $item->setQtvincativos($qtVincativos);
        $item->setNrcagedmagnet(\HCM\Util\NovoCodigo::geraCodigo($nrorg, 'FPA_CAGEDMAGNET', 1, 12, true));
        $this->addItem($item);

    }


    /**
     * Insere ou atualiza registro.
     *
     * @param string $nrorg            Numero da organizacao.
     * @param string $mesCompetencia   Mes de competencia.
     * @param string $tipoRegistro     Tipo de registro CAGED.
     * @param string $tipoInscricao    Tipo de inscricao.
     * @param string $nrInscricao      Numero de inscricao.
     * @param string $linha            Linha do registro.
     * @param string $nrVinculoM       Numero do vinculo.
     * @param string $dataAdmissao     Data de admissao do vinculo.
     * @param string $nrPisPasepCi     Numero de inscricao (PIS/PASEP/CI).
     * @param string $tipoMovimentacao Tipo de movimentacao de transferencia (legal/gerencial).
     *
     * @return void
     *
     */
    public function persisteRegistro(
        $nrorg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao,
        $linha, $nrVinculoM, $dataAdmissao, $nrPisPasepCi, $tipoMovimentacao, $dtRescisaovinc
    ){
        // Procura o registro na base.
        $item = $this->entityManager->getRepository(Repositories::FPA_CAGEDMAGNET)->retornaRegistrosTrabalhador(
            $mesCompetencia, $nrorg, $tipoRegistro, $tipoInscricao, $nrInscricao, $nrPisPasepCi, $dataAdmissao, $tipoMovimentacao, $this->hcmParameters->getCdoperador()
            );
        if (is_object($item) === true) {
            //$item->setNrcagedmagnet($item->getNrcagedmagnet());
            $item->setDslinharegistro($linha);
        } else {
            $item = new FpaCagedmagnet();
            $item->setIdativo('S'); // Verificar.
            $item->setNrorg($nrorg);
            $item->setMescompetencia($mesCompetencia);
            $item->setIdtiporegistro($tipoRegistro);
            $item->setIdtpinscestrutu($tipoInscricao);
            $item->setCdinscestrut($nrInscricao);
            $item->setNrvinculom($nrVinculoM);
            $item->setDtadmissaovinc($dataAdmissao);
            $item->setNrpispaseppes($nrPisPasepCi);
            $item->setDslinharegistro($linha);
            $item->setNrtpmovtransfm($tipoMovimentacao);
            $item->setDtrescisaovinc($dtRescisaovinc);
            $item->setNrorginclusao($nrorg);
            $item->setNrorgultatu($nrorg);
            $item->setDtultatu(new DateTime());
            $item->setDtinclusao(new DateTime());
            $item->setCdoperultatu($this->hcmParameters->getCdoperador());
            $item->setCdoperinclusao($this->hcmParameters->getCdoperador());
            $item->setNrcagedmagnet(\HCM\Util\NovoCodigo::geraCodigo($nrorg, 'FPA_CAGEDMAGNET', 1, 12, true));
        }
        
        $this->entityManager->persist($item);
        $this->entityManager->flush($item);

    }


    /**
     * Procura registro na lista.
     *
     * @param string $nrInscricao    Numero da inscricao da empresa.
     * @param string $tpRegistro     Numero do tipo do registro.
     *
     * @return boolean
     *
     */
    public function procuraRegistroLista($nrInscricao, $tpRegistro, $cdoperinclusao, $nrorg) {
        $itens = $this->getItems();
        foreach ($itens as $key => $item) {
             if (($item->getCdinscestrut() === $nrInscricao)
                && ($item->getIdtiporegistro() === $tpRegistro)
                && ($item->getCdoperinclusao() == $cdoperinclusao)
                && ($item->getNrorginclusao() == $nrorg)
            ) {
                return $key;
            }
        }

        return false;
    }


    /**
     * Remove todos os registros da Org. no mes de competencia.
     *
     * @param integer $nrorg          Numero da Organizacao.
     * @param string  $mesCompetencia Mes de competencia.
     *
     * @return void
     *
     */
    public function retroceder($nrorg, $mesCompetencia, $cdOperador){
//        $registros = $this->retornaRegistros($mesCompetencia, $nrorg, $cdOperador);
        $this->entityManager->getRepository(Repositories::FPA_CAGEDMAGNET)->retrocederCaged($nrorg, $mesCompetencia, $cdOperador);
        /*$query = $this->entityManager->getConnection()->prepare("
          DELETE FROM FPA_CAGEDMAGNET WHERE NRORG = :NRORG AND MESCOMPETENCIA = :MESCOMPETENCIA AND CDOPERINCLUSAO = :CDOPERINCLUSAO
        ");

        $return = $query->execute(
            array(
                "NRORG"            => $nrorg,
                "MESCOMPETENCIA"   => $mesCompetencia,
                "CDOPERINCLUSAO"   => $cdOperador
            )
        );*/
    }


    /**
     * Retorna o total de registros de acordo com o tipo de registro informado.
     *
     * @param string  $mesCompetencia Mes de competencia.
     * @param integer $nrorg          Numero da organizacao.
     * @param integer $tipoRegistro   Tipo do registro.
     *
     * @return number
     *
     */
    

}